FrontendMessage

Enum FrontendMessage 

pub enum FrontendMessage {
Show 18 variants Query { sql: String, }, Parse { name: String, sql: String, param_types: Vec<u32>, }, DescribeStatement { name: String, }, DescribePortal { name: String, }, Bind { portal_name: String, statement_name: String, param_formats: Vec<Format>, raw_params: Vec<Option<Vec<u8>>>, result_formats: Vec<Format>, }, Execute { portal_name: String, max_rows: i32, }, Flush, Sync, CloseStatement { name: String, }, ClosePortal { name: String, }, Terminate, CopyData(Vec<u8>), CopyDone, CopyFail(String), RawAuthentication(Vec<u8>), Password { password: String, }, SASLInitialResponse { gs2_header: GS2Header, mechanism: String, initial_response: SASLInitialResponse, }, SASLResponse(SASLClientFinalResponse),
}
A decoded frontend pgwire message, representing instructions for the backend.

Variants



Query

Execute the specified SQL.

This is issued as part of the simple query flow.

Fields

sql: String

The SQL to execute.



Parse

Parse the specified SQL into a prepared statement.

This starts the extended query flow.

Fields

name: String

The name of the prepared statement to create. An empty string specifies the unnamed prepared statement.

sql: String

The SQL to parse.

param_types: Vec<u32>

The OID of each parameter data type for which the client wants to prespecify types. A zero OID is equivalent to leaving the type unspecified.

The number of specified parameter data types can be less than the number of parameters specified in the query.



DescribeStatement

Describe an existing prepared statement.

This command is part of the extended query flow.

Fields

name: String

The name of the prepared statement to describe.



DescribePortal

Describe an existing portal.

This command is part of the extended query flow.

Fields

name: String

The name of the portal to describe.



Bind

Bind an existing prepared statement to a portal.

This command is part of the extended query flow.

Fields

portal_name: String

The destination portal. An empty string selects the unnamed portal. The portal can later be executed with the Execute command.

statement_name: String

The source prepared statement. An empty string selects the unnamed prepared statement.

param_formats: Vec<Format>

The formats used to encode the parameters in raw_parameters.

raw_params: Vec<Option<Vec<u8>>>

The value of each parameter, encoded using the formats described by parameter_formats.

result_formats: Vec<Format>

The desired formats for the columns in the result set.



Execute

Execute a bound portal.

This command is part of the extended query flow.

Fields

portal_name: String

The name of the portal to execute.

max_rows: i32

The maximum number number of rows to return before suspending.

0 or negative means infinite.



Flush

Flush any pending output.

This command is part of the extended query flow.



Sync

Finish an extended query.

This command is part of the extended query flow.



CloseStatement

Close the named statement.

This command is part of the extended query flow.

Fields

name: String


ClosePortal

Close the named portal.

Fields

name: String


Terminate

Terminate a connection.



CopyData(Vec<u8>)



CopyDone



CopyFail(String)



RawAuthentication(Vec<u8>)



Password

Fields

password: String


SASLInitialResponse

Fields

gs2_header: GS2Header
mechanism: String
initial_response: SASLInitialResponse


SASLResponse(SASLClientFinalResponse)

Implementations

Source

impl FrontendMessage

pub fn encode(&self, dst: &mut BytesMut) -> Result<(), Error>

Encodes self into dst.

Source

impl FrontendMessage

pub fn name(&self) -> &'static str