pub enum FrontendMessage {
Show 18 variants
Query {
sql: String,
},
Parse {
name: String,
sql: String,
param_types: Vec<u32>,
},
DescribeStatement {
name: String,
},
DescribePortal {
name: String,
},
Bind {
portal_name: String,
statement_name: String,
param_formats: Vec<Format>,
raw_params: Vec<Option<Vec<u8>>>,
result_formats: Vec<Format>,
},
Execute {
portal_name: String,
max_rows: i32,
},
Flush,
Sync,
CloseStatement {
name: String,
},
ClosePortal {
name: String,
},
Terminate,
CopyData(Vec<u8>),
CopyDone,
CopyFail(String),
RawAuthentication(Vec<u8>),
Password {
password: String,
},
SASLInitialResponse {
gs2_header: GS2Header,
mechanism: String,
initial_response: SASLInitialResponse,
},
SASLResponse(SASLClientFinalResponse),
}Expand description
A decoded frontend pgwire message, representing instructions for the backend.
Variants
Query
Execute the specified SQL.
This is issued as part of the simple query flow.
Parse
Parse the specified SQL into a prepared statement.
This starts the extended query flow.
Fields
DescribeStatement
Describe an existing prepared statement.
This command is part of the extended query flow.
DescribePortal
Describe an existing portal.
This command is part of the extended query flow.
Bind
Bind an existing prepared statement to a portal.
This command is part of the extended query flow.
Fields
portal_name: StringThe destination portal. An empty string selects the unnamed
portal. The portal can later be executed with the Execute command.
statement_name: StringThe source prepared statement. An empty string selects the unnamed prepared statement.
Execute
Execute a bound portal.
This command is part of the extended query flow.
Fields
Flush
Flush any pending output.
This command is part of the extended query flow.
Sync
Finish an extended query.
This command is part of the extended query flow.
CloseStatement
Close the named statement.
This command is part of the extended query flow.
ClosePortal
Close the named portal.
Terminate
Terminate a connection.
CopyData(Vec<u8>)
CopyDone
CopyFail(String)
RawAuthentication(Vec<u8>)
Password
SASLInitialResponse
SASLResponse(SASLClientFinalResponse)
Implementations